==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfComboBoxWidgetFieldWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfComboBoxWidgetFieldWidget(PdfChoiceWidgetFieldWidget):
    """
    Represents the combo box field of an existing item.
    """

    @property
    def Editable(self) -> bool:
        """
        Gets or sets a value indicating whether this is editable.
        :return: True if the drop down list is editable, false otherwise. Default is false.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable.restype = c_bool
        ret = GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable(self.Ptr)
        return ret

    @Editable.setter
    def Editable(self, value: bool):
        """
        Sets a value indicating whether this is editable.
        :param value: True if the drop down list is editable, false otherwise.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_Editable.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_Editable(self.Ptr, value)

    @property
    def WidgetItems(self) -> 'PdfComboBoxWidgetItemCollection':
        """
        Gets the collection of combo box items.
        :return: The collection of combo box items.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems.restype = c_void_p
        intPtr = GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems(self.Ptr)
        ret = None if intPtr == None else PdfComboBoxWidgetItemCollection(intPtr)
        return ret

    @property
    def SelectedValue(self) -> str:
        """
        Gets the selected value of the combo box.
        :return: The selected value of the combo box.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue(self.Ptr))
        return ret

    @SelectedValue.setter
    def SelectedValue(self, value: str):
        """
        Sets the selected value of the combo box.
        :param value: The selected value of the combo box.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_SelectedValue.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_SelectedValue(self.Ptr, value)

    def ObjectID(self) -> int:
        """
        Gets the form field identifier.
        :return: The form field identifier.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID.restype = c_int
        ret = GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID(self.Ptr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfComboBoxWidgetFieldWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfComboBoxWidgetFieldWidget(PdfChoiceWidgetFieldWidget):
    """
    Represents the combo box field of an existing item.
    """

    @property
    def Editable(self) -> bool:
        """
        Gets or sets a value indicating whether this is editable.
        :return: True if the drop down list is editable, false otherwise. Default is false.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_Editable,self.Ptr)
        return ret

    @Editable.setter
    def Editable(self, value: bool):
        """
        Sets a value indicating whether this is editable.
        :param value: True if the drop down list is editable, false otherwise.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_Editable.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_Editable,self.Ptr, value)

    @property
    def WidgetItems(self) -> 'PdfComboBoxWidgetItemCollection':
        """
        Gets the collection of combo box items.
        :return: The collection of combo box items.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_WidgetItems,self.Ptr)
        ret = None if intPtr == None else PdfComboBoxWidgetItemCollection(intPtr)
        return ret

    @property
    def SelectedValue(self) -> str:
        """
        Gets the selected value of the combo box.
        :return: The selected value of the combo box.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_get_SelectedValue,self.Ptr))
        return ret

    @SelectedValue.setter
    def SelectedValue(self, value: str):
        """
        Sets the selected value of the combo box.
        :param value: The selected value of the combo box.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_SelectedValue.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_set_SelectedValue,self.Ptr, value)

    def ObjectID(self) -> int:
        """
        Gets the form field identifier.
        :return: The form field identifier.
        """
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfComboBoxWidgetFieldWidget_ObjectID,self.Ptr)
        return ret
